summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rwxr-xr-xsrc/device.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/device.c b/src/device.c
index ffec3f2c..53aa1110 100755
--- a/src/device.c
+++ b/src/device.c
@@ -270,11 +270,11 @@ int __connman_device_enable(struct connman_device *device)
}
/*
* if err == -EINPROGRESS, then the DBus call to the respective daemon
* was successful. We set a 4 sec timeout so if the daemon never
* returns a reply, we would reset the pending request.
*/
if (err == -EINPROGRESS)
- device->pending_timeout = g_timeout_add_seconds(4,
+ device->pending_timeout = g_timeout_add_seconds(10,
device_pending_reset, device);
done:
return err;
@@ -270,11 +270,11 @@ int __connman_device_enable(struct connman_device *device)
/*
* if err == -EINPROGRESS, then the DBus call to the respective daemon
- * was successful. We set a 4 sec timeout so if the daemon never
+ * was successful. We set a 10 sec timeout so if the daemon never
* returns a reply, we would reset the pending request.
*/